pub struct DeviceInfo {
pub id: DeviceID,
pub output_channels: u32,
pub input_channels: u32,
pub duplex_channels: u32,
pub is_default_output: bool,
pub is_default_input: bool,
pub native_formats: NativeFormats,
pub preferred_sample_rate: u32,
pub sample_rates: Vec<u32>,
}Expand description
Queried information about a device.
Fields
id: DeviceIDThe unique identifier of this device.
output_channels: u32The number of output channels on this device.
input_channels: u32The number of input channels on this device.
duplex_channels: u32The number of duplex channels on this device.
is_default_output: boolWhether or not this device is the default output device.
is_default_input: boolWhether or not this device is the default input device.
native_formats: NativeFormatsThe native sample formats that this device supports. (bitflags)
Note you can still start a stream with any format. RtAudio will just automatically convert to/from the best native format.
preferred_sample_rate: u32The device’s preferred sample rate.
sample_rates: Vec<u32>The available sample rates for this device.
Implementations
Sourceimpl DeviceInfo
impl DeviceInfo